
<?php
include_once '../includes/db_connection.php';
include_once '../includes/sanitize.php';
include_once '../includes/session_management.php';

// Sipariş Oluşturma Fonksiyonu
function createOrder($user_id) {
    $conn = getDbConnection();
    $conn->autocommit(FALSE); // Otomatik commit devre dışı bırakılıyor

    // Sepetten ürünleri al
    $cart_sql = "SELECT product_id, quantity FROM cart WHERE user_id = ?";
    $stmt = $conn->prepare($cart_sql);
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows == 0) {
        echo json_encode(["status" => "error", "message" => "Sepetinizde ürün yok."], JSON_UNESCAPED_UNICODE);
        $stmt->close();
        $conn->close();
        exit;
    }

    $total_price = 0;
    $products = [];
    while ($row = $result->fetch_assoc()) {
        $product_id = $row['product_id'];
        $quantity = $row['quantity'];

        // Ürün bilgilerini al ve fiyatı hesapla
        $product_sql = "SELECT price, stock FROM products WHERE product_id = ?";
        $stmt_product = $conn->prepare($product_sql);
        $stmt_product->bind_param("i", $product_id);
        $stmt_product->execute();
        $stmt_product->bind_result($price, $stock);
        $stmt_product->fetch();
        $stmt_product->close();

        if ($stock < $quantity) {
            echo json_encode(["status" => "error", "message" => "Yeterli stok yok."], JSON_UNESCAPED_UNICODE);
            $conn->close();
            exit;
        }

        $total_price += $price * $quantity;
        $products[] = [
            'product_id' => $product_id,
            'quantity' => $quantity,
            'price' => $price
        ];
    }

    // Kullanıcının bakiyesi kontrol ediliyor
    $balance_sql = "SELECT balance FROM users WHERE user_id = ?";
    $stmt_balance = $conn->prepare($balance_sql);
    $stmt_balance->bind_param("i", $user_id);
    $stmt_balance->execute();
    $stmt_balance->bind_result($balance);
    $stmt_balance->fetch();
    $stmt_balance->close();

    if ($balance < $total_price) {
        echo json_encode(["status" => "error", "message" => "Bakiyeniz bu siparişi gerçekleştirmek için yeterli değil."], JSON_UNESCAPED_UNICODE);
        $conn->close();
        exit;
    }

    // Siparişi oluştur
    $order_sql = "INSERT INTO orders (user_id, total_price, status) VALUES (?, ?, 'pending')";
    $stmt_order = $conn->prepare($order_sql);
    $stmt_order->bind_param("id", $user_id, $total_price);
    if (!$stmt_order->execute()) {
        $conn->rollback();
        echo json_encode(["status" => "error", "message" => "Sipariş oluşturulamadı."], JSON_UNESCAPED_UNICODE);
        exit;
    }

    $order_id = $stmt_order->insert_id;

    // Ürün stoklarını güncelle ve sipariş ürünlerini ekle
    foreach ($products as $product) {
        $new_stock = $stock - $product['quantity'];
        $update_stock_sql = "UPDATE products SET stock = ? WHERE product_id = ?";
        $stmt_update_stock = $conn->prepare($update_stock_sql);
        $stmt_update_stock->bind_param("ii", $new_stock, $product['product_id']);
        if (!$stmt_update_stock->execute()) {
            $conn->rollback();
            echo json_encode(["status" => "error", "message" => "Stok güncellenemedi."], JSON_UNESCAPED_UNICODE);
            exit;
        }
        $stmt_update_stock->close();

        $order_item_sql = "INSERT INTO order_items (order_id, product_id, quantity, price) VALUES (?, ?, ?, ?)";
        $stmt_order_item = $conn->prepare($order_item_sql);
        $stmt_order_item->bind_param("iiid", $order_id, $product['product_id'], $product['quantity'], $product['price']);
        if (!$stmt_order_item->execute()) {
            $conn->rollback();
            echo json_encode(["status" => "error", "message" => "Sipariş ürünleri eklenemedi."], JSON_UNESCAPED_UNICODE);
            exit;
        }
        $stmt_order_item->close();
    }

    // Kullanıcının bakiyesini güncelle
    $new_balance = $balance - $total_price;
    $update_balance_sql = "UPDATE users SET balance = ? WHERE user_id = ?";
    $stmt_update_balance = $conn->prepare($update_balance_sql);
    $stmt_update_balance->bind_param("di", $new_balance, $user_id);
    if (!$stmt_update_balance->execute()) {
        $conn->rollback();
        echo json_encode(["status" => "error", "message" => "Bakiye güncellenemedi."], JSON_UNESCAPED_UNICODE);
        exit;
    }
    $stmt_update_balance->close();

    // Sepeti temizle
    $delete_cart_sql = "DELETE FROM cart WHERE user_id = ?";
    $stmt_delete_cart = $conn->prepare($delete_cart_sql);
    $stmt_delete_cart->bind_param("i", $user_id);
    if (!$stmt_delete_cart->execute()) {
        $conn->rollback();
        echo json_encode(["status" => "error", "message" => "Sepet temizlenemedi."], JSON_UNESCAPED_UNICODE);
        exit;
    }
    $stmt_delete_cart->close();

    $conn->commit(); // İşlemleri onayla
    echo json_encode(["status" => "success", "message" => "Sipariş başarıyla oluşturuldu."], JSON_UNESCAPED_UNICODE);

    $stmt_order->close();
    $conn->close();
}

if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_GET['action']) && $_GET['action'] == 'create_order') {
    if (!isLoggedIn()) {
        echo json_encode(["status" => "error", "message" => "Lütfen önce giriş yapın."], JSON_UNESCAPED_UNICODE);
        exit;
    }
    $user_id = $_SESSION['user_id'];
    header('Content-Type: application/json');
    createOrder($user_id);
    exit;
}
?>
